@@ -74,6 +74,10 @@ class PostgresTargetConnector(C8Connector):
         """Get supported schemas using the given configurations."""
         return []
 
+    def reserved_keys(self) -> list[str]:
+        """List of reserved keys for the connector."""
+        return []
+
     def config(self) -> list[ConfigProperty]:
         """Get configuration parameters for the connector."""
         return [
